Views
=====

.. module:: invenio_sword.views

Blueprint creation
------------------

.. autofunction:: create_blueprint


View classes
------------

.. autoclass:: SWORDDepositView
   :members:

.. autoclass:: ServiceDocumentView
   :members:

.. autoclass:: DepositStatusView
   :members:

.. autoclass:: DepositMetadataView
   :members:

.. autoclass:: DepositFilesetView
   :members:

.. autoclass:: DepositFileView
   :members:
